Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(751)

Unified Diff: chrome/browser/sync/profile_sync_service_android.h

Issue 23643002: Enable invalidations for arbitrary objects on Android. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/sync/profile_sync_service_android.h
diff --git a/chrome/browser/sync/profile_sync_service_android.h b/chrome/browser/sync/profile_sync_service_android.h
index fc4732e54bb7121e0be78064ea3ea516a3c0fd79..19ec2a3fb8458ea6bdbb4aa80e29be761529899c 100644
--- a/chrome/browser/sync/profile_sync_service_android.h
+++ b/chrome/browser/sync/profile_sync_service_android.h
@@ -33,10 +33,12 @@ class ProfileSyncServiceAndroid : public ProfileSyncServiceObserver {
// This method should be called once right after contructing the object.
void Init();
// Called from Java when we need to nudge native syncer. The |objectId|,
// |version| and |payload| values should come from an invalidation.
void NudgeSyncer(JNIEnv* env,
jobject obj,
+ jint objectSource,
jstring objectId,
jlong version,
jstring payload);
@@ -210,9 +212,11 @@ class ProfileSyncServiceAndroid : public ProfileSyncServiceObserver {
virtual ~ProfileSyncServiceAndroid();
// Remove observers to profile sync service.
void RemoveObserver();
- // Called from Java when we need to nudge native syncer. The |objectId|,
- // |version| and |payload| values should come from an invalidation.
- void SendNudgeNotification(const std::string& str_object_id,
+ // Called from Java when we need to nudge native syncer. The |object_source|,
+ // |objectId|, |version| and |payload| values should come from an
+ // invalidation.
+ void SendNudgeNotification(int object_source,
+ const std::string& str_object_id,
int64 version,
const std::string& payload);
« no previous file with comments | « chrome/browser/invalidation/invalidation_service_factory.cc ('k') | chrome/browser/sync/profile_sync_service_android.cc » ('j') | no next file with comments »
@@ -33,10 +33,12 @@ class ProfileSyncServiceAndroid : public ProfileSyncServiceObserver {
// This method should be called once right after contructing the object.
void Init();
- // Called from Java when we need to nudge native syncer. The |objectId|,
- // |version| and |payload| values should come from an invalidation.
+ // Called from Java when we need to nudge native syncer. The |objectSource|,
+ // |objectId|, |version| and |payload| values should come from an
+ // invalidation.
void NudgeSyncer(JNIEnv* env,
jobject obj,

Powered by Google App Engine
This is Rietveld 408576698